@@ -31,6 +31,9 @@ typedef struct {
 	/* Reference count */
 	guint ref_count;
 
+	/* Name of file this image was loaded from */
+	char *filename;
+
 	/* Buffer with original image data */
 	GdkPixbuf *pixbuf;
 
