@@ -430,10 +430,10 @@ static GnomeUIInfo main_menu[] = {
  * window_get_type:
  * @void:
  *
- * Registers the &Window class if necessary, and returns the type ID associated
+ * Registers the #Window class if necessary, and returns the type ID associated
  * to it.
  *
- * Return value: the type ID of the &Window class.
+ * Return value: the type ID of the #Window class.
  **/
 GtkType
 window_get_type (void)
@@ -704,6 +704,8 @@ window_open_image (Window *window, const char *filename)
 	WindowPrivate *priv;
 	Image *image;
 	gboolean retval;
+	char *fname;
+	gboolean free_fname;
 
 	g_return_val_if_fail (window != NULL, FALSE);
 	g_return_val_if_fail (IS_WINDOW (window), FALSE);
@@ -717,6 +719,26 @@ window_open_image (Window *window, const char *filename)
 	image = image_new ();
 	retval = image_load (image, filename);
 	ui_image_set_image (UI_IMAGE (priv->content), image);
+
+	free_fname = FALSE;
+
+	if (image->filename) {
+		if (image->pixbuf) {
+			fname = g_strdup_printf ("%s (%dx%d)",
+						 g_basename (image->filename),
+						 gdk_pixbuf_get_width (image->pixbuf),
+						 gdk_pixbuf_get_height (image->pixbuf));
+			free_fname = TRUE;
+		} else
+			fname = g_basename (image->filename);
+	} else
+		fname = _("Eye of Gnome");
+
+	gtk_window_set_title (GTK_WINDOW (window), fname);
+
+	if (free_fname)
+		g_free (fname);
+
 	image_unref (image);
 	return retval;
 }
